#
# spec file for package cookiecutter
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2017 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cookiecutter
Version:        1.7.0
Release:        lp152.1.1
Summary:        A command-line utility that creates projects from project templates
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/audreyr/cookiecutter
Source:         https://files.pythonhosted.org/packages/source/c/cookiecutter/cookiecutter-%{version}.tar.gz
Source1:        ccext.py
BuildRequires:  git
BuildRequires:  python3-Jinja2 >= 2.7
BuildRequires:  python3-binaryornot >= 0.2.0
BuildRequires:  python3-click >= 7.0
BuildRequires:  python3-devel
BuildRequires:  python3-future >= 0.15.2
BuildRequires:  python3-jinja2-time >= 0.1.0
BuildRequires:  python3-poyo >= 0.1.0
BuildRequires:  python3-setuptools
BuildRequires:  python3-whichcraft >= 0.4.0
Requires:       git
Requires:       python3-Jinja2 >= 2.7
Requires:       python3-binaryornot >= 0.2.0
Requires:       python3-click >= 7.0
Requires:       python3-future >= 0.15.2
Requires:       python3-jinja2-time >= 0.1.0
Requires:       python3-poyo >= 0.1.0
Requires:       python3-requests >= 2.18.0
Requires:       python3-whichcraft >= 0.4.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION Testing requirements
BuildRequires:  python3-chardet >= 2.0.0
BuildRequires:  python3-freezegun
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-cov
BuildRequires:  python3-pytest-mock
BuildRequires:  python3-requests >= 2.18.0
# /SECTION
# SECTION Documentation requirements
BuildRequires:  python3-Sphinx
BuildRequires:  python3-recommonmark
# /SECTION

%package doc
Summary:        Documentation files for %{name}
Group:          Documentation/HTML

%description
A command-line utility that creates projects from cookiecutters (project
templates), e.g. creating a Python package project from a Python package
project template.

Project templates can be in any programming language or markup format.

%description doc
A command-line utility that creates projects from cookiecutters (project
templates), e.g. creating a Python package project from a Python package
project template.

This package contains the documentation for cookiecutter.

%prep
%setup -q -n cookiecutter-%{version}
sed -i "s/cookiecutter =/cookiecutter-%{py3_ver} =/" setup.py
cp %{SOURCE1} docs

%build
python3 setup.py build
pushd docs
make %{?_smp_mflags} html
rm _build/html/.buildinfo
popd

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/cookiecutter
ln -sf %{_sysconfdir}/alternatives/cookiecutter %{buildroot}%{_bindir}/cookiecutter

%check
export LC_ALL=en_US.UTF-8
export LANG=en_US.UTF-8
PYTHONPATH=%{buildroot}%{python3_sitelib} py.test tests

%pre
[ -h %{_bindir}/cookiecutter ] || rm -f %{_bindir}/cookiecutter

%post
update-alternatives --install %{_bindir}/cookiecutter cookiecutter %{_bindir}/cookiecutter-%{py3_ver} 30

%postun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove cookiecutter %{_bindir}/cookiecutter-%{py3_ver}
fi

%files
%license LICENSE
%ghost %{_sysconfdir}/alternatives/cookiecutter
%{_bindir}/cookiecutter
%{_bindir}/cookiecutter-%{py3_ver}
%{python3_sitelib}/*

%files doc
%doc docs/_build/html
%license LICENSE

%changelog
* Wed Jan  1 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove obsolete patch fix-python-invocation-tests.diff
- remove obsolete patch cookiecutter-click7.patch
- update to version 1.7.0:
  * Important Changes:
  * Drop support for EOL Python 3.4, thanks to [@jamescurtin](https://github.com/jamescurtin) and [@insspb](https://github.com/insspb) (#1024)
  * Drop support for EOL Python 3.3, thanks to [@hugovk](https://github.com/hugovk) (#1024)
  * Increase the minimum click version to 7.0, thanks to [@rly](https://github.com/rly) and [@luzfcb](https://github.com/luzfcb) (#1168)
  * Other Changes:
  * PEP257 fixing docstrings in exceptions.py. Thanks to [@MinchinWeb](https://github.com/MinchinWeb) (#1237)
  * PEP257 fixing docstrings in replay.py. Thanks to [@kishan](https://github.com/kishan3) (#1234)
  * PEP257 fixing docstrings in test_unzip.py. Thanks to [@tonytheleg](https://github.com/tonytheleg) and [@insspb](https://github.com/insspb) (#1236, #1262)
  * Fixed tests sequence for appveyor, to exclude file not found bug. Thanks to [@insspb](https://github.com/insspb) (#1257)
  * Updates REAMDE.md with svg badge for appveyor. Thanks to [@sobolevn](https://github.com/sobolevn) (#1254)
  * Add missing {%% endif %%} to Choice Variables example. Thanks to [@mattstibbs](https://github.com/mattstibbs) (#1249)
  * Core documentation converted to Markdown format thanks to [@wagnernegrao](https://github.com/wagnernegrao), [@insspb](https://github.com/insspb) (#1216)
  * Tests update: use sys.executable when invoking python in python 3 only environment thanks to [@vincentbernat](https://github.com/vincentbernat) (#1221)
  * Prevent `click` API v7.0 from showing choices when already shown, thanks to [@rly](https://github.com/rly) and [@luzfcb](https://github.com/luzfcb) (#1168)
  * Test the codebase with python3.8 beta on tox and travis-ci (#1206), thanks to [@mihrab34](https://github.com/mihrab34)
  * Add a [CODE\_OF\_CONDUCT.md](https://github.com/audreyr/cookiecutter/blob/master/CODE_OF_CONDUCT.md) file to the project, thanks to [@andreagrandi](https://github.com/andreagrandi) (#1009)
  * Update docstrings in `cookiecutter/main.py`, `cookiecutter/__init__.py`, and `cookiecutter/log.py` to follow the PEP 257 style guide, thanks to [@meahow](https://github.com/meahow) (#998, #999, #1000)
  * Update docstrings in `cookiecutter/utils.py` to follow the PEP 257 style guide, thanks to [@dornheimer](https://github.com/dornheimer)(#1026)
  * Fix grammar in *Choice Variables* documentation, thanks to [@jubrilissa](https://github.com/jubrilissa) (#1011)
  * Update installation docs with links to the Windows Subsystem and GNU utilities, thanks to [@Nythiennzo](https://github.com/Nythiennzo) for the PR and [@BruceEckel](https://github.com/BruceEckel) for the review (#1016)
  * Upgrade flake8 to version 3.5.0, thanks to [@cclauss](https://github.com/cclauss) (#1038)
  * Update tutorial with explanation for how cookiecutter finds the template file, thanks to [@accraze](https://github.com/accraze)(#1025)
  * Update CI config files to use `TOXENV` environment variable, thanks to [@asottile](https://github.com/asottile) (#1019)
  * Improve user documentation for writing hooks, thanks to [@jonathansick](https://github.com/jonathansick) (#1057)
  * Make sure to preserve the order of items in the generated cookiecutter context, thanks to [@hackebrot](https://github.com/hackebrot) (#1074)
  * Fixed DeprecationWarning for a regular expression on python 3.6, thanks to [@reinout](https://github.com/reinout) (#1124)
  * Document use of cookiecutter-template topic on GitHub, thanks to [@ssbarnea](https://github.com/ssbarnea) (#1189)
  * Update README badge links, thanks to [@luzfcb](https://github.com/luzfcb) (#1207)
  * Update prompt.py to match pep257 guidelines, thanks to [@jairideout](https://github.com/jairideout) (#1105)
  * Update link to Jinja2 extensions documentation, thanks to [@dacog](https://github.com/dacog) (#1193)
  * Require pip 9.0.0 or newer for tox environments, thanks to [@hackebrot](https://github.com/hackebrot) (#1215)
  * Use io.open contextmanager when reading hook files, thanks to [@jcb91](https://github.com/jcb91) (#1147)
  * Add more cookiecutter templates to the mix:
  * [cookiecutter-python-cli](https://github.com/xuanluong/cookiecutter-python-cli) by [@xuanluong](https://github.com/xuanluong) (#1003)
  * [cookiecutter-docker-science](https://github.com/docker-science/cookiecutter-docker-science) by [@takahi-i](https://github.com/takahi-i) (#1040)
  * [cookiecutter-flask-skeleton](https://github.com/realpython/cookiecutter-flask-skeleton) by [@mjhea0](https://github.com/mjhea0) (#1052)
  * [cookiecutter-awesome](https://github.com/Pawamoy/cookiecutter-awesome) by [@Pawamoy](https://github.com/Pawamoy) (#1051)
  * [cookiecutter-flask-ask](https://github.com/chrisvoncsefalvay/cookiecutter-flask-ask) by [@machinekoder](https://github.com/machinekoder) (#1056)
  * [cookiecutter-data-driven-journalism](https://github.com/jastark/cookiecutter-data-driven-journalism) by [@JAStark](https://github.com/JAStark) (#1020)
  * [cookiecutter-tox-plugin](https://github.com/tox-dev/cookiecutter-tox-plugin) by [@obestwalter](https://github.com/obestwalter) (#1103)
  * [cookiecutter-django-dokku](https://github.com/mashrikt/cookiecutter-django-dokku) by [@mashrikt](https://github.com/mashrikt) (#1093)
* Wed Jan  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to build with new click cookiecutter-click7.patch
* Wed Feb 21 2018 sebix+novell.com@sebix.at
-  update to version 1.6.0:
  * Include template path or template URL in cookiecutter context under _template
  * Add a URL abbreviation for GitLab template projects
  * Add option to use templates from Zip files or Zip URLs
  * bugfixes
- update to version 1.5.1:
  * bugfixes
- remove fix-caplog-tests.diff, it broke the tests
- remove separate specfile for docs, use one combined
* Fri Feb  3 2017 hpj@urpla.net
- version 1.5.0: initial build
